@@ -26,7 +26,7 @@ def test_normal_default():
 def test_env_var():
     os.environ['FAVCOLOR'] = 'blue'
     parser = SettingsParser()
-    parser.add_argument('--color', env_var_name='FAVCOLOR')
+    parser.add_argument('--color', env_var='FAVCOLOR')
     args = parser.parse_args([])
     assert args.color == 'blue'
 
@@ -43,7 +43,7 @@ def test_yaml_value():
 
 def test_env_var_default_used():
     parser = SettingsParser()
-    parser.add_argument('--color', env_var_name='FAVCOLOR', default='green')
+    parser.add_argument('--color', env_var='FAVCOLOR', default='green')
 
     # Make sure there's not actually a FAVCOLOR env var
     if 'FAVCOLOR' in os.environ:
